@@ -18,6 +18,17 @@ MainWindow::MainWindow(QWidget *parent) :
     progress3.setWindowModality(Qt::WindowModal);
     progress3.setWindowTitle(varattu3);
     progress3.setCancelButton(0);
+
+    if (!QFile::exists("/opt/theme-customizer/cssuinstalled")) {
+        ui->pushButton_2->setDisabled(true);
+    } else if (QFile::exists("/opt/theme-customizer/cssuinstalled")){
+        ui->Icons->setDisabled(true);
+        ui->horizontalSlider->setDisabled(true);
+        ui->horizontalSlider_2->setDisabled(true);
+        ui->lineEdit->setDisabled(true);
+        ui->lineEdit_2->setDisabled(true);
+    }
+
     progress3.setValue(0);
     progress3.show();
     progress3.setValue(5);
@@ -915,7 +926,7 @@ void MainWindow::on_about_triggered()
     msgBox.setWindowTitle(tr("About Theme Customizer"));
     msgBox.setText("Author: d-iivil - Licence: Freeware & open source (GPL)");
     msgBox.setTextFormat(Qt::RichText);
-    msgBox.setInformativeText("<html>Version: 0.9-70<br /><a href=\"https://www.paypal.com/cgi-bin/webscr?cmd=_donations&business=ricky%40hevikaraoke%2efi&lc=FI&item_name=Here%27s%20some%20money%20for%20beer%2e&no_note=0&currency_code=EUR&bn=PP%2dDonationsBF%3abtn_donate_SM%2egif%3aNonHostedGuest\">Be a nice guy and <b>donate some money for beer</b> to author</a></html>");
+    msgBox.setInformativeText("<html>Version: 0.9-71<br /><a href=\"https://www.paypal.com/cgi-bin/webscr?cmd=_donations&business=ricky%40hevikaraoke%2efi&lc=FI&item_name=Here%27s%20some%20money%20for%20beer%2e&no_note=0&currency_code=EUR&bn=PP%2dDonationsBF%3abtn_donate_SM%2egif%3aNonHostedGuest\">Be a nice guy and <b>donate some money for beer</b> to author</a></html>");
     msgBox.setStandardButtons(QMessageBox::Ok);
     msgBox.setDefaultButton(QMessageBox::Ok);
     msgBox.button(msgBox.Ok)->setText(tr("Ok, thanks."));
